
# Slot: quantifier qualifier


can be used to indicate magnitude, or also ranking

URI: [biolink:gene_to_expression_site_association_quantifier_qualifier](https://w3id.org/biolink/vocab/gene_to_expression_site_association_quantifier_qualifier)


## Domain and Range

[GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md) &#8594;  <sub>0..1</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [quantifier qualifier](quantifier_qualifier.md)

## Children


## Used by

 * [GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Narrow Mappings:** | | LOINC:analyzes |
|  | | LOINC:measured_by |
|  | | LOINC:property_of |
|  | | SEMMEDDB:measures |
|  | | UMLS:measures |

